"""Inject the current working directory into Context"""

import os

import pyblish.backend.lib
import pyblish.backend.plugin


@pyblish.backend.lib.log
class SelectCurrentWorkingDirectory(pyblish.backend.plugin.Selector):
    """Append the currently working directory"""

    hosts = ['*']
    version = (0, 1, 0)

    def process_context(self, context):
        context.set_data('cwd', value=os.getcwd())



"""Inject the currently logged on user into the Context"""

import getpass

import pyblish.backend.lib
import pyblish.backend.plugin


@pyblish.backend.lib.log
class SelectCurrentUser(pyblish.backend.plugin.Selector):
    """Append the currently logged on user"""

    hosts = ['*']
    version = (0, 1, 0)

    def process_context(self, context):
        context.set_data('user', value=getpass.getuser())



import logging

from .version import *


def get_formatter():
    formatter = logging.Formatter(
        '%(asctime)s - '
        '%(levelname)s - '
        '%(name)s - '
        '%(message)s',
        '%H:%M:%S')
    return formatter


def setup_log():
    log = logging.getLogger('pyblish')

    if log.handlers:
        return log.handlers[0]

    log.setLevel(logging.DEBUG)
    # log.setLevel(logging.INFO)
    # log.setLevel(logging.WARNING)

    formatter = get_formatter()
    stream_handler = logging.StreamHandler()
    stream_handler.setFormatter(formatter)
    log.addHandler(stream_handler)

    return log




import pyblish.backend.lib
import pyblish.backend.plugin


@pyblish.backend.lib.log
class SelectInstances(pyblish.backend.plugin.Selector):
    """Select instances"""

    hosts = ['python']
    version = (0, 1, 0)

    def process_context(self, context):
        instance = context.create_instance(name='inst1')

        for node in ('node1_PLY', 'node2_PLY', 'node3_GRP'):
            instance.add(node)

        for key, value in {'publishable': True,
                           'family': 'test',
                           'startFrame': 1001,
                           'endFrame': 1025}.iteritems():

            instance.set_data(key, value)

        context.add(instance)

        return



"""Inject the current time into the Context"""

import time

import pyblish.backend.lib
import pyblish.backend.plugin
import pyblish.backend.config


@pyblish.backend.lib.log
class SelectCurrentDate(pyblish.backend.plugin.Selector):
    """Append the currently working directory"""

    hosts = ['*']
    version = (0, 1, 0)

    def process_context(self, context):
        """Formatting is coming from configuration"""
        date = time.strftime(pyblish.backend.config.date_format)
        context.set_data('date', value=date)
